Class: Aws::GeoMaps::Types::GetTileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geomaps/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:z, :x, :y, :key]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters such as map styles that can be requested for each result. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Array<String>)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end

#tilesetString

Specifies the desired tile set. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the `vector.basemap` value.

Valid Values: ‘raster.satellite | vector.basemap | vector.traffic | raster.dem`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end

#xString

The X axis value for the map tile.

Returns:

  • (String)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end

#yString

The Y axis value for the map tile.

Returns:

  • (String)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end

#zString

The zoom value for the map tile.

Returns:

  • (String)


944
945
946
947
948
949
950
951
952
953
# File 'lib/aws-sdk-geomaps/types.rb', line 944

class GetTileRequest < Struct.new(
  :additional_features,
  :tileset,
  :z,
  :x,
  :y,
  :key)
  SENSITIVE = [:z, :x, :y, :key]
  include Aws::Structure
end