Class: Aws::GeoMaps::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GeoMaps::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-geomaps/client.rb
Overview
An API client for GeoMaps. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::GeoMaps::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_glyphs(params = {}) ⇒ Types::GetGlyphsResponse
‘GetGlyphs` returns the map’s glyphs.
-
#get_sprites(params = {}) ⇒ Types::GetSpritesResponse
‘GetSprites` returns the map’s sprites.
-
#get_static_map(params = {}) ⇒ Types::GetStaticMapResponse
<note markdown=“1”> This operation is not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
-
#get_style_descriptor(params = {}) ⇒ Types::GetStyleDescriptorResponse
‘GetStyleDescriptor` returns information about the style.
-
#get_tile(params = {}) ⇒ Types::GetTileResponse
‘GetTile` returns a tile.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-geomaps/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1448 1449 1450 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1448 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1451 1452 1453 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1451 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1421 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::GeoMaps') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-geomaps' context[:gem_version] = '1.26.0' Seahorse::Client::Request.new(handlers, context) end |
#get_glyphs(params = {}) ⇒ Types::GetGlyphsResponse
‘GetGlyphs` returns the map’s glyphs.
For more information, see [Style labels with glyphs] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/styling-labels-with-glyphs.html
685 686 687 688 |
# File 'lib/aws-sdk-geomaps/client.rb', line 685 def get_glyphs(params = {}, = {}, &block) req = build_request(:get_glyphs, params) req.send_request(, &block) end |
#get_sprites(params = {}) ⇒ Types::GetSpritesResponse
‘GetSprites` returns the map’s sprites.
For more information, see [Style iconography with sprites] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/styling-iconography-with-sprites.html
756 757 758 759 |
# File 'lib/aws-sdk-geomaps/client.rb', line 756 def get_sprites(params = {}, = {}, &block) req = build_request(:get_sprites, params) req.send_request(, &block) end |
#get_static_map(params = {}) ⇒ Types::GetStaticMapResponse
<note markdown=“1”> This operation is not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
</note>
`GetStaticMap` provides high-quality static map images with
customizable options. You can modify the map’s appearance and overlay additional information. It’s an ideal solution for applications requiring tailored static map snapshots.
For more information, see the following topics in the *Amazon
Location Service Developer Guide*:
* [Static maps][2]
- Customize static maps][3
- Overlay on the static map][4
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html [2]: docs.aws.amazon.com/location/latest/developerguide/static-maps.html [3]: docs.aws.amazon.com/location/latest/developerguide/customizing-static-maps.html [4]: docs.aws.amazon.com/location/latest/developerguide/overlaying-static-map.html
1149 1150 1151 1152 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1149 def get_static_map(params = {}, = {}, &block) req = build_request(:get_static_map, params) req.send_request(, &block) end |
#get_style_descriptor(params = {}) ⇒ Types::GetStyleDescriptorResponse
‘GetStyleDescriptor` returns information about the style.
For more information, see [Style dynamic maps] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/styling-dynamic-maps.html
1331 1332 1333 1334 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1331 def get_style_descriptor(params = {}, = {}, &block) req = build_request(:get_style_descriptor, params) req.send_request(, &block) end |
#get_tile(params = {}) ⇒ Types::GetTileResponse
‘GetTile` returns a tile. Map tiles are used by clients to render a map. They’re addressed using a grid arrangement with an X coordinate, Y coordinate, and Z (zoom) level.
For more information, see [Tiles] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/tiles.html
1412 1413 1414 1415 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1412 def get_tile(params = {}, = {}, &block) req = build_request(:get_tile, params) req.send_request(, &block) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1441 1442 1443 |
# File 'lib/aws-sdk-geomaps/client.rb', line 1441 def waiter_names [] end |