Class: Aws::GeoMaps::Types::GetStyleDescriptorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoMaps::Types::GetStyleDescriptorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geomaps/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:political_view, :key]
Instance Attribute Summary collapse
-
#buildings ⇒ String
Adjusts how building details are rendered on the map.
-
#color_scheme ⇒ String
Sets the color tone for the map, such as dark and light.
-
#contour_density ⇒ String
Displays the shape and steepness of terrain features using elevation lines.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#poi_categories ⇒ Array<String>
Renders only the specified categories of points of interest.
-
#poi_density ⇒ String
Controls how densely points of interest are rendered on the map.
-
#political_view ⇒ String
Specifies the political view using ISO 3166-2 or ISO 3166-3 country code format.
-
#style ⇒ String
Style specifies the desired map style.
-
#terrain ⇒ String
Adjusts how physical terrain details are rendered on the map.
-
#traffic ⇒ String
Displays real-time traffic information overlay on map, such as incident events and flow events.
-
#travel_modes ⇒ Array<String>
Renders additional map information relevant to selected travel modes.
Instance Attribute Details
#buildings ⇒ String
Adjusts how building details are rendered on the map.
The following building styles are currently supported:
Buildings3D: Displays buildings as three-dimensional extrusions on the map.
^
Buildings3D is valid only for the Standard and Monochrome map
styles.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#color_scheme ⇒ String
Sets the color tone for the map, such as dark and light.
Example: Light
Default value: Light
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#contour_density ⇒ String
Displays the shape and steepness of terrain features using elevation
lines. The density value controls how densely the available contour
line information is rendered on the map. Not supported in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
This parameter is valid for all map styles except Satellite.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#poi_categories ⇒ Array<String>
Renders only the specified categories of points of interest. When you omit this parameter, the map renders all categories.
The following categories are currently supported:
-
FoodAndDrink -
Entertainment -
SightsAndMuseums -
Transportation -
Accommodations -
LeisureAndOutdoor -
Shopping -
BusinessAndServices -
FacilitiesAndBuildings
Specify each category as a separate poi-categories query
parameter. Duplicate values are rejected.
poi-density is set to Off,
which hides all points of interest regardless of category.
This parameter is valid only for the Standard and Hybrid map
styles. In ap-southeast-1 and ap-southeast-5 regions for
GrabMaps customers, this parameter is valid only for the
Standard map style.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#poi_density ⇒ String
Controls how densely points of interest are rendered on the map. The density value controls the zoom level at which each category of points of interest appears, and how quickly less prominent points of interest are revealed as you zoom in. Denser values display more points of interest at lower zoom levels.
Use Off to hide all points of interest. When you omit this
parameter, the map renders at Default density.
This parameter is valid only for the Standard and Hybrid map
styles. In ap-southeast-1 and ap-southeast-5 regions for
GrabMaps customers, this parameter is valid only for the
Standard map style.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#political_view ⇒ String
Specifies the political view using ISO 3166-2 or ISO 3166-3 country
code format. Not supported in ap-southeast-1 and ap-southeast-5
regions for GrabMaps customers.
The following political views are currently supported:
-
ARG: Argentina's view on the Southern Patagonian Ice Field and Tierra Del Fuego, including the Falkland Islands, South Georgia, and South Sandwich Islands -
EGY: Egypt's view on Bir Tawil -
IND: India's view on Gilgit-Baltistan -
KEN: Kenya's view on the Ilemi Triangle -
MAR: Morocco's view on Western Sahara -
RUS: Russia's view on Crimea -
SDN: Sudan's view on the Halaib Triangle -
SRB: Serbia's view on Kosovo, Vukovar, and Sarengrad Islands -
SUR: Suriname's view on the Courantyne Headwaters and Lawa Headwaters -
SYR: Syria's view on the Golan Heights -
TUR: Turkey's view on Cyprus and Northern Cyprus -
TZA: Tanzania's view on Lake Malawi -
URY: Uruguay's view on Rincon de Artigas -
VNM: Vietnam's view on the Paracel Islands and Spratly Islands
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#style ⇒ String
Style specifies the desired map style. For GrabMaps customers,
ap-southeast-1 and ap-southeast-5 regions support only the
Standard and Monochrome values.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#terrain ⇒ String
Adjusts how physical terrain details are rendered on the map. Not
supported in ap-southeast-1 and ap-southeast-5 regions for
GrabMaps customers.
The following terrain styles are currently supported:
-
Hillshade: Displays the physical terrain details through shading and highlighting of elevation change and geographic features. -
Terrain3D: Displays physical terrain details and elevations as a three-dimensional model.
Hillshade is valid only for the Standard and Monochrome map
styles.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#traffic ⇒ String
Displays real-time traffic information overlay on map, such as
incident events and flow events. Not supported in ap-southeast-1
and ap-southeast-5 regions for GrabMaps customers.
This parameter is valid for all map styles except Satellite.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |
#travel_modes ⇒ Array<String>
Renders additional map information relevant to selected travel
modes. Information for multiple travel modes can be displayed
simultaneously, although this increases the overall information
density rendered on the map. Not supported in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
This parameter is valid for all map styles except Satellite.
927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-geomaps/types.rb', line 927 class GetStyleDescriptorRequest < Struct.new( :style, :color_scheme, :political_view, :terrain, :contour_density, :traffic, :travel_modes, :buildings, :poi_density, :poi_categories, :key) SENSITIVE = [:political_view, :key] include Aws::Structure end |