Class: Aws::GeoMaps::Types::GetTileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoMaps::Types::GetTileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geomaps/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:z, :x, :y, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters such as map styles that can be requested for each result.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#tileset ⇒ String
Specifies the desired tile set.
-
#x ⇒ String
The X axis value for the map tile.
-
#y ⇒ String
The Y axis value for the map tile.
-
#z ⇒ String
The zoom value for the map tile.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters such as map styles that can be requested for each result. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |
#tileset ⇒ String
Specifies the desired tile set. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the `vector.basemap` value.
Valid Values: ‘raster.satellite | vector.basemap | vector.traffic | raster.dem`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |
#x ⇒ String
The X axis value for the map tile.
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |
#y ⇒ String
The Y axis value for the map tile.
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |
#z ⇒ String
The zoom value for the map tile.
944 945 946 947 948 949 950 951 952 953 |
# File 'lib/aws-sdk-geomaps/types.rb', line 944 class GetTileRequest < Struct.new( :additional_features, :tileset, :z, :x, :y, :key) SENSITIVE = [:z, :x, :y, :key] include Aws::Structure end |